import {
  collection,
  onSnapshot,
  // orderBy,
  query,
  where,
} from 'firebase/firestore';
import { useEffect, useState } from 'react';

import { useParams } from 'react-router-dom';
import { useRecoilValue, useRecoilState } from 'recoil';

import { productIdAtom } from '../../pages/ProductDetail/ProductInquiry/@recoil/productId';
import { db } from '../app.js';

import { productListFamily } from '@/store/productListState.js';

export const useDetailCollection = (collectionName) => {
  const [dataState, setDataState] = useState();
  const { productId } = useParams();
  const product = useRecoilValue(productListFamily(productId));
  const [productIdState, setProductIdState] = useRecoilState(productIdAtom);

  // 상품 ID가 변경되면 productIdState 아톰 업데이트
  useEffect(() => {
    setProductIdState(product.id);
  }, [product.id]);

  // productIdState 아톰이 업데이트 되면 이펙트 콜백
  useEffect(() => {
    if (productIdState) {
      console.log(`콜렉션 이름: ${collectionName}`);

      const sortCollectionRecentDate = query(
        collection(db, collectionName),
        where('productId', '==', productIdState)
        // Firestore 색인(index) 생성에 문제가 있는 지 정렬 동시 사용에 오류 발생
        // orderBy('date', 'desc')
      );

      const unsub = onSnapshot(sortCollectionRecentDate, (snapshot) => {
        let dataArr = [];

        snapshot.docs.forEach((doc) => {
          dataArr.push({ ...doc.data() });
        });

        // Front-end 개발 단에서 내림차순 정렬 처리
        dataArr.sort(({ date: aDate }, { date: bDate }) => {
          // 오름차순 정렬
          // return aDate.toDate() - bDate.toDate();

          // 내림차순 정렬
          return bDate.toDate() - aDate.toDate();
        });

        setDataState(dataArr);
      });

      return unsub;
    }
  }, [productIdState]);

  // 디버깅
  // useEffect(() => {
  //   console.log({ dataState });
  // }, [dataState]);

  return { dataState };
};
